@@ -30,6 +30,7 @@ import sys
 _modules = {
     'mysql': 'MySQLdb',
     'postgresql': 'psycopg',
+    'tsearch2': 'psycopg',
 }
 
 def get_backend(name):
@@ -43,7 +44,7 @@ def get_backend(name):
     try:
         module = __import__(module_name, vars)
     except:
-        # import failed, but in versions prior to 2.4, a (broken) 
+        # import failed, but in versions prior to 2.4, a (broken)
         # module is left in sys.modules and package globals;
         # subsequent imports would succeed and get the broken module.
         # This no longer happens in Python 2.4 and later.
@@ -57,6 +58,9 @@ def get_backend(name):
 
 def have_backend(name):
     '''Is backend "name" available?'''
+    if name == 'tsearch2':
+        # currently not working
+        return 0
     try:
         get_backend(name)
         return 1
