@@ -100,7 +100,7 @@ class _Database(hyperdb.Database, roundupdb.Database):
         self.stats = {'cache_hits': 0, 'cache_misses': 0, 'get_items': 0,
             'filtering': 0}
 
-        os.umask(0002)
+        os.umask(config.UMASK)
 
     def post_init(self):
         if self.indexer.should_reindex():
@@ -1778,9 +1778,12 @@ _typmap = {
 class FileClass(hyperdb.FileClass, Class):
     ''' like Class but with a content property
     '''
-    default_mime_type = 'text/plain'
     def __init__(self, db, classname, **properties):
-        properties['content'] = FileName()
+        '''The newly-created class automatically includes the "content"
+        and "type" properties.
+        '''
+        if not properties.has_key('content'):
+            properties['content'] = hyperdb.String(indexme='yes')
         if not properties.has_key('type'):
             properties['type'] = hyperdb.String()
         Class.__init__(self, db, classname, **properties)
@@ -1908,24 +1911,32 @@ class FileClass(hyperdb.FileClass, Class):
             f.write(content)
             f.close()
 
-            mimetype = propvalues.get('type', self.default_mime_type)
-            self.db.indexer.add_text((self.classname, itemid, 'content'),
-                content, mimetype)
+            if self.properties['content'].indexme:
+                mimetype = self.get('type', self.default_mime_type)
+                self.db.indexer.add_text((self.classname, itemid, 'content'),
+                    content, mimetype)
 
         self.fireReactors('set', oldnode, propvalues)
 
     def index(self, nodeid):
-        '''Add (or refresh) the node to search indexes.
+        ''' Add (or refresh) the node to search indexes.
 
-        Pass on the content-type property for the content property.
+        Use the content-type property for the content property.
         '''
-        Class.index(self, nodeid)
-        try:
-            mime_type = self.get(nodeid, 'type', self.default_mime_type)
-        except KeyError:
-            mime_type = self.default_mime_type
-        self.db.indexer.add_text((self.classname, nodeid, 'content'),
-            str(self.get(nodeid, 'content')), mime_type)
+        # find all the String properties that have indexme
+        for prop, propclass in self.getprops().items():
+            if prop == 'content' and propclass.indexme:
+                mime_type = self.get(nodeid, 'type', self.default_mime_type)
+                self.db.indexer.add_text((self.classname, nodeid, 'content'),
+                    str(self.get(nodeid, 'content')), mime_type)
+            elif isinstance(propclass, hyperdb.String) and propclass.indexme:
+                # index them under (classname, nodeid, property)
+                try:
+                    value = str(self.get(nodeid, prop))
+                except IndexError:
+                    # node has been destroyed
+                    continue
+                self.db.indexer.add_text((self.classname, nodeid, prop), value)
 
 class IssueClass(Class, roundupdb.IssueClass):
     ''' The newly-created class automatically includes the "messages",
