@@ -66,7 +66,7 @@ def db_nuke(config):
             tables = cursor.fetchall()
             # stupid MySQL bug requires us to drop all the tables first
             for table in tables:
-                command = 'DROP TABLE %s'%table[0]
+                command = 'DROP TABLE `%s`'%table[0]
                 if __debug__:
                     logging.getLogger('hyperdb').debug(command)
                 cursor.execute(command)
@@ -183,6 +183,13 @@ class Database(Database):
         else:
             self.database_schema = {}
 
+    def save_dbschema(self):
+        ''' Save the schema definition that the database currently implements
+        '''
+        s = repr(self.database_schema)
+        self.sql('delete from `schema`')
+        self.sql('insert into `schema` values (%s)', (s,))
+
     def create_version_2_tables(self):
         # OTK store
         self.sql('''CREATE TABLE otks (otk_key VARCHAR(255),
