@@ -1,3 +1,4 @@
+#$Id$
 #
 # Copyright (c) 2003 Martynas Sklyzmantas, Andrey Lebedev <andrey@micro.lt>
 #
@@ -26,7 +27,7 @@ def connection_dict(config, dbnamestr=None):
 
 def db_create(config):
     """Clear all database contents and drop database itself"""
-    command = 'CREATE DATABASE %s'%config.RDBMS_NAME
+    command = "CREATE DATABASE %s WITH ENCODING='UNICODE'"%config.RDBMS_NAME
     logging.getLogger('hyperdb').info(command)
     db_command(config, command)
 
@@ -216,9 +217,8 @@ class Database(rdbms_common.Database):
 
         # reset the sequences
         for cn in self.classes.keys():
-            self.sql('DROP SEQUENCE _%s_ids'%cn)
-            self.sql('CREATE SEQUENCE _%s_ids'%cn)
-
+            self.cursor.execute('DROP SEQUENCE _%s_ids'%cn)
+            self.cursor.execute('CREATE SEQUENCE _%s_ids'%cn)
 
 
 class Class(rdbms_common.Class):
