@@ -94,7 +94,7 @@ class Database(rdbms_common.Database):
 
     def open_connection(self):
         # ensure files are group readable and writable
-        os.umask(0002)
+        os.umask(self.config.UMASK)
 
         (self.conn, self.cursor) = self.sql_open_connection()
 
@@ -168,7 +168,7 @@ class Database(rdbms_common.Database):
                 continue
             # it's a multilink, and it's been removed - drop the old
             # table. First drop indexes.
-            self.drop_multilink_table_indexes(spec.classname, ml)
+            self.drop_multilink_table_indexes(spec.classname, name)
             sql = 'drop table %s_%s'%(spec.classname, prop)
             self.sql(sql)
         old_has = old_has.has_key
@@ -325,12 +325,18 @@ class Database(rdbms_common.Database):
     def setid(self, classname, setid):
         ''' Set the id counter: used during import of database
 
-        We add one to make it behave like the seqeunces in postgres.
+        We add one to make it behave like the sequences in postgres.
         '''
         sql = 'update ids set num=%s where name=%s'%(self.arg, self.arg)
         vals = (int(setid)+1, classname)
         self.sql(sql, vals)
 
+    def clear(self):
+        rdbms_common.Database.clear(self)
+        # set the id counters to 0 (setid adds one) so we start at 1
+        for cn in self.classes.keys():
+            self.setid(cn, 0)
+
     def create_class(self, spec):
         rdbms_common.Database.create_class(self, spec)
         sql = 'insert into ids (name, num) values (%s, %s)'
