@@ -1,13 +1,15 @@
+#$Id$
 ''' This implements the full-text indexer over two RDBMS tables. The first
 is a mapping of words to occurance IDs. The second maps the IDs to (Class,
 propname, itemid) instances.
 '''
 import re
 
-from indexer_dbm import Indexer, is_stopword
+from roundup.backends.indexer_common import Indexer as IndexerBase
 
-class Indexer(Indexer):
+class Indexer(IndexerBase):
     def __init__(self, db):
+        IndexerBase.__init__(self, db)
         self.db = db
         self.reindex = 0
 
@@ -16,6 +18,11 @@ class Indexer(Indexer):
         # just nuke the circular reference
         self.db = None
 
+    def save_index(self):
+        '''Save the changes to the index.'''
+        # not necessary - the RDBMS connection will handle this for us
+        pass
+
     def force_reindex(self):
         '''Force a reindexing of the database.  This essentially
         empties the tables ids and index and sets a flag so
@@ -56,7 +63,7 @@ class Indexer(Indexer):
                 for w in re.findall(r'(?u)\b\w{2,25}\b', text)]
         words = {}
         for word in wordlist:
-            if is_stopword(word): continue
+            if self.is_stopword(word): continue
             if len(word) > 25: continue
             words[word] = 1
         words = words.keys()
@@ -128,21 +135,5 @@ class Indexer(Indexer):
 
             self.db.cursor.execute(sql, tuple(map(int, r)))
 
-        # self.search_index has the results as {some id: identifier} ...
-        # sigh
-        r = {}
-        k = 0
-        for c,n,p in self.db.cursor.fetchall():
-            key = (str(c), str(n), str(p))
-            r[k] = key
-            k += 1
-        return r
-
-    def save_index(self):
-        # the normal RDBMS backend transaction mechanisms will handle this
-        pass
-
-    def rollback(self):
-        # the normal RDBMS backend transaction mechanisms will handle this
-        pass
+        return self.db.cursor.fetchall()
 
