@@ -853,7 +853,7 @@ reply's additional "Re:" is ok),
 """ % {'name': user_props['username'], 'tracker': tracker_name,
         'url': self.base, 'otk': otk}
         if not self.client.standard_message([user_props['address']], subject,
-                body):
+                body, (tracker_name, tracker_email)):
             return
 
         # commit changes to the database
