@@ -458,14 +458,15 @@ class Client:
                     user = username
 
         # if user was not set by http authorization, try session cookie
-        if (not user) and self.cookie.has_key(self.cookie_name) \
-        and (self.cookie[self.cookie_name].value != 'deleted'):
+        if (not user and self.cookie.has_key(self.cookie_name)
+                and (self.cookie[self.cookie_name].value != 'deleted')):
             # get the session key from the cookie
             self.session = self.cookie[self.cookie_name].value
             # get the user from the session
             try:
                 # update the lifetime datestamp
                 sessions.updateTimestamp(self.session)
+                self.db.commit()
                 user = sessions.get(self.session, 'user')
             except KeyError:
                 # not valid, ignore id
