@@ -318,8 +318,8 @@ class FormParser:
                 continue
             proptype = propdef[propname]
 
-            # Get the form value. This value may be a MiniFieldStorage or a list
-            # of MiniFieldStorages.
+            # Get the form value. This value may be a MiniFieldStorage
+            # or a list of MiniFieldStorages.
             value = form[key]
 
             # handle unpacking of the MiniFieldStorage / list form value
@@ -463,15 +463,18 @@ class FormParser:
 
                 # "missing" existing values may not be None
                 if not existing:
-                    if isinstance(proptype, hyperdb.String) and not existing:
+                    if isinstance(proptype, hyperdb.String):
                         # some backends store "missing" Strings as empty strings
-                        existing = None
-                    elif isinstance(proptype, hyperdb.Number) and not existing:
+                        if existing == self.db.BACKEND_MISSING_STRING:
+                            existing = None
+                    elif isinstance(proptype, hyperdb.Number):
                         # some backends store "missing" Numbers as 0 :(
-                        existing = 0
-                    elif isinstance(proptype, hyperdb.Boolean) and not existing:
+                        if existing == self.db.BACKEND_MISSING_NUMBER:
+                            existing = None
+                    elif isinstance(proptype, hyperdb.Boolean):
                         # likewise Booleans
-                        existing = 0
+                        if existing == self.db.BACKEND_MISSING_BOOLEAN:
+                            existing = None
 
                 # if changed, set it
                 if value != existing:
@@ -510,7 +513,7 @@ class FormParser:
                 'Required %(class)s properties %(property)s not supplied',
                 len(required)
             ) % {
-                'class': thing[0],
+                'class': self._(thing[0]),
                 'property': ', '.join(map(self.gettext, required))
             })
         if s:
@@ -521,7 +524,10 @@ class FormParser:
         # either have a non-empty content property or no property at all. In
         # the latter case, nothing will change.
         for (cn, id), props in all_props.items():
-            if isinstance(self.db.classes[cn], hyperdb.FileClass):
+            if (id == '-1') and not props:
+                # new item (any class) with no content - ignore
+                del all_props[(cn, id)]
+            elif isinstance(self.db.classes[cn], hyperdb.FileClass):
                 if id == '-1':
                     if not props.get('content', ''):
                         del all_props[(cn, id)]
@@ -550,3 +556,5 @@ class FormParser:
 
         # filter out the empty bits
         return filter(None, value)
+
+# vim: set et sts=4 sw=4 :
