@@ -663,11 +663,10 @@ class HTMLClass(HTMLInputMixin, HTMLPermissions):
             properties = ','.join(properties)
         if sort is None:
             if 'username' in properties.split( ',' ):
-                sort = '&amp;@sort=username'
+                sort = 'username'
             else:
-                sort = ''
-        else:
-            sort = '&amp;@sort=' + sort
+                sort = find_sort_key(self._klass)
+        sort = '&amp;@sort=' + sort
         if property:
             property = '&amp;property=%s'%property
         if form:
@@ -1762,7 +1761,7 @@ class LinkHTMLProperty(HTMLProperty):
         options = [opt
             for opt in linkcl.filter(None, conditions, sort_on, (None, None))
             if self._db.security.hasPermission("View", self._client.userid,
-                linkcl.classname, itemid=id)]
+                linkcl.classname, itemid=opt)]
 
         # make sure we list the current value if it's retired
         if value and value not in options:
@@ -1948,7 +1947,7 @@ class MultilinkHTMLProperty(HTMLProperty):
         options = [opt
             for opt in linkcl.filter(None, conditions, sort_on)
             if self._db.security.hasPermission("View", self._client.userid,
-                linkcl.classname, itemid=id)]
+                linkcl.classname, itemid=opt)]
         height = height or min(len(options), 7)
         l = ['<select multiple name="%s" size="%s">'%(self._formname, height)]
         k = linkcl.labelprop(1)
