@@ -45,7 +45,7 @@ date_re = re.compile(r'''^
     ((?P<y>\d\d\d\d)([/-](?P<m>\d\d?)([/-](?P<d>\d\d?))?)? # yyyy[-mm[-dd]]
     |(?P<a>\d\d?)[/-](?P<b>\d\d?))?              # or mm-dd
     (?P<n>\.)?                                   # .
-    (((?P<H>\d?\d):(?P<M>\d\d))?(:(?P<S>\d\d(\.\d+)?))?)?  # hh:mm:ss
+    (((?P<H>\d?\d):(?P<M>\d\d))?(:(?P<S>\d\d?(\.\d+)?))?)?  # hh:mm:ss
     (?P<o>[\d\smywd\-+]+)?                       # offset
 $''', re.VERBOSE)
 serialised_date_re = re.compile(r'''
@@ -391,7 +391,7 @@ class Date:
         return str
 
     def __repr__(self):
-        return '<Date %s>'%self.formal(sec='%f')
+        return '<Date %s>'%self.formal(sec='%06.3f')
 
     def local(self, offset):
         """ Return this date as yyyy-mm-dd.hh:mm:ss in a local time zone.
@@ -408,7 +408,7 @@ class Date:
             self.second, 0, 0, 0)
 
     def serialise(self):
-        return '%4d%02d%02d%02d%02d%f'%(self.year, self.month,
+        return '%4d%02d%02d%02d%02d%06.3f'%(self.year, self.month,
             self.day, self.hour, self.minute, self.second)
 
     def timestamp(self):
