@@ -855,6 +855,15 @@ class FileClass:
     ''' A class that requires the "content" property and stores it on
         disk.
     '''
+    default_mime_type = 'text/plain'
+
+    def __init__(self, db, classname, **properties):
+        '''The newly-created class automatically includes the "content"
+        property.
+        '''
+        if not properties.has_key('content'):
+            properties['content'] = hyperdb.String(indexme='yes')
+
     def export_propnames(self):
         ''' Don't export the "content" property
         '''
