@@ -3,7 +3,7 @@
 __docformat__ = 'restructuredtext'
 # $Id$
 
-import time, quopri, os, socket, smtplib, re
+import time, quopri, os, socket, smtplib, re, sys, traceback
 
 from cStringIO import StringIO
 from MimeWriter import MimeWriter
@@ -14,8 +14,8 @@ from roundup import __version__
 try:
     from email.Utils import formatdate
 except ImportError:
-    def formatdate(timeval):
-        return time.strftime("%a, %d %b %Y %H:%M:%S +0000", timeval)
+    def formatdate():
+        return time.strftime("%a, %d %b %Y %H:%M:%S +0000", time.gmtime())
 
 class MessageSendError(RuntimeError):
     pass
@@ -60,7 +60,7 @@ class Mailer:
         writer.addheader('Subject', encode_header(subject, charset))
         writer.addheader('To', ', '.join(to))
         writer.addheader('From', author)
-        writer.addheader('Date', formatdate(time.gmtime()))
+        writer.addheader('Date', formatdate())
 
         # Add a unique Roundup header to help filtering
         writer.addheader('X-Roundup-Name', encode_header(tracker_name,
@@ -143,6 +143,15 @@ class Mailer:
 
         self.smtp_send(to, message)
 
+    def exception_message(self):
+        '''Send a message to the admins with information about the latest
+        traceback.
+        '''
+        subject = '%s: %s'%(self.config.TRACKER_NAME, sys.exc_info()[1])
+        to = [self.config.ADMIN_EMAIL]
+        content = '\n'.join(traceback.format_exception(*sys.exc_info()))
+        self.standard_message(to, subject, content)
+
     def smtp_send(self, to, message):
         """Send a message over SMTP, using roundup's config.
 
@@ -180,7 +189,7 @@ class SMTPConnection(smtplib.SMTP):
         # start the TLS if requested
         if config["MAIL_TLS"]:
             self.starttls(config["MAIL_TLS_KEYFILE"],
-                config["MAIL_TLS_CERFILE"])
+                config["MAIL_TLS_CERTFILE"])
 
         # ok, now do we also need to log in?
         mailuser = config["MAIL_USERNAME"]
