@@ -18,6 +18,10 @@
 # 
 # $Id$
 
+"""Enforces the minimum Python version that Roundup requires.
+"""
+__docformat__ = 'restructuredtext'
+
 import sys
 if not hasattr(sys, 'version_info') or sys.version_info[:3] < (2,1,1):
     print "Content-Type: text/plain\n"
