@@ -424,15 +424,30 @@ class FormTestCase(unittest.TestCase):
     def testSetNumber(self):
         self.assertEqual(self.parseForm({'number': '1'}),
             ({('test', None): {'number': 1}}, []))
+        self.assertEqual(self.parseForm({'number': '0'}),
+            ({('test', None): {'number': 0}}, []))
         self.assertEqual(self.parseForm({'number': '\n0\n'}),
             ({('test', None): {'number': 0}}, []))
+
+    def testSetNumberReplaceOne(self):
         nodeid = self.db.test.create(number=1)
         self.assertEqual(self.parseForm({'number': '1'}, 'test', nodeid),
             ({('test', nodeid): {}}, []))
+        self.assertEqual(self.parseForm({'number': '0'}, 'test', nodeid),
+            ({('test', nodeid): {'number': 0}}, []))
+
+    def testSetNumberReplaceZero(self):
         nodeid = self.db.test.create(number=0)
         self.assertEqual(self.parseForm({'number': '0'}, 'test', nodeid),
             ({('test', nodeid): {}}, []))
 
+    def testSetNumberReplaceNone(self):
+        nodeid = self.db.test.create()
+        self.assertEqual(self.parseForm({'number': '0'}, 'test', nodeid),
+            ({('test', nodeid): {'number': 0}}, []))
+        self.assertEqual(self.parseForm({'number': '1'}, 'test', nodeid),
+            ({('test', nodeid): {'number': 1}}, []))
+
     def testEmptyNumberSet(self):
         nodeid = self.db.test.create(number=0)
         self.assertEqual(self.parseForm({'number': ''}, 'test', nodeid),
