@@ -84,6 +84,12 @@ class DateTestCase(unittest.TestCase):
         date = Date("8:47:11", -5)
         ae(str(date), '%s-%02d-%02d.13:47:11'%(y, m, d))
 
+        # just make sure we parse these, m'kay?
+        date = Date('-1d')
+        date = Date('-1w')
+        date = Date('-1m')
+        date = Date('-1y')
+
     def testOffsetRandom(self):
         ae = self.assertEqual
         # XXX unsure of the usefulness of these, they're pretty random
